13/03/99 12:32:17
   
extension
	"Returns the default extension for the receiver's pathName."

	^'zip'!  
openWrite: aPathName
	"Returns an open instance of the receiver or nil if failed."

	| result |
	result := self new.
	^(result openWrite: aPathName) ifTrue: [ result ]
!   
extension
	"Returns the default extension for the receiver's pathName.
	Returns an empty string as default this method can be refined by subclasses."

	^String new!  
openRead: aPathName
	"Returns an open instance of the receiver or nil if failed."

	| result |
	result := self new.
	^(result openRead: aPathName) ifTrue: [ result ]
! 
asParameter
	"Answer the receiver in a form suitable for passing as a parameter to a host procedure call."

	^handle asParameter!  
closeFile
	"Close and opened/internal file."

	self mode = #read
	ifTrue: [
		UnzOk = (self dll unzCloseCurrentFile: self asParameter)
		ifFalse: [ self error: 'Can''t close current file.' ].
	]
	ifFalse: [
		ZipOk = (self dll zipCloseFileInZip: self asParameter)
		ifFalse: [ self error: 'Can''t close current file.' ].
	].!  
openCurrentFile
	"Open the current file."

	self mustBeReading.
	UnzOk = (self dll unzOpenCurrentFile: self asParameter)
	ifFalse: [ self error: 'Can''t open current file.' ].! 
pathName: anObject
    "Sets the instance var of the receiver
     with anObject. (No checking is done)"
    pathName := anObject! 
withAllFileInfosDo: aBlock
	"Evaluates aBlock with all the receiver's fileInfos."

	^self withAllFileInfosAndNamesDo: [:info :fileName| aBlock value: info ]!  
globalInfo
	" Private - Returns the global info structure (or nil if failed). "

	| globalInfo result |
	self mustBeReading.
	globalInfo := self dll structureNamed: 'unz_global_info'.
	result := self dll unzGetGlobalInfo: self asParameter global: globalInfo asParameter.
	result = UnzOk ifFalse: [ ^nil ].
	^globalInfo!   
withAllFileNamesDo: aBlock
	"Evaluates aBlock with all the receiver's fileInfos."

	^self withAllFileInfosAndNamesDo: [:info :fileName| aBlock value: fileName ]!  
fileNames
	"Returns all the zip file names."

	| fileNames |
	fileNames := OrderedCollection new: 100.
	self withAllFileNamesDo: [:fileName| fileNames add: fileName].
	^fileNames asArray! 
release
	"Free the resource associated with the receiver."

	self close.
	super release.! 
createFile: fileName
	"Open the current file."

	^self
		createFile: fileName
		comment: nil
		method: ZDeflated
		level: ZDefaultCompression! 
createFile: fileName comment: comment
	"Open the current file."

	^self
		createFile: fileName
		comment: comment
		method: ZDeflated
		level: ZDefaultCompression!
createFile: fileName method: method level: level
	"Open the current file."

	^self
		createFile: fileName
		comment: nil
		method: method
		level: level!  
locateFile: fileName caseSensitivity: caseSensitivity
	"Try locate the file fileName in the receiver.
	Returns true if success and position the receiver at this file."

	self mustBeReading.
	^UnzOk = (self dll
		unzLocateFile: self asParameter
		fileName: fileName asParameter
		caseSensitivity: caseSensitivity asParameter)! 
getCurrentFileInfoAndFileName
	"Returns the current file info and fileName of the file where the receiver is positioned."

	| fileInfo fileName |
	self mustBeReading.
	fileName := String new: 1024.
	fileInfo := self dll structureNamed: 'unz_file_info'.

	(self dll unzGetCurrentFileInfo: self asParameter
		 info: fileInfo filename: fileName) = UnzOk
	ifFalse: [ self error: 'Can''t obtain file information.' ].

	^Array with: fileInfo with: fileName trimBlanks
!  
openRead: aPathName
	"Returns true if the receiver can open the zip file pathName."

	self close.
	handle := self dll unzOpen: aPathName asParameter.
	handle = 0 ifTrue: [
		( (aPathName includes: $.) not
		and: [self class extension size > 0])
		ifTrue: [
			^self openRead: aPathName,'.',self class extension
		].
		^false
	].
	pathName := aPathName.
	mode := #read.
	^true!   
openWrite: aPathName
	"Returns true if the receiver can open the zip file pathName
	to be written."

	^self openWrite: aPathName append: false!   
readCurrentFileInto: byteObject
	"Read byteObject from the current file.
	WARNING: The current file must be opened.
	Returns the number of bytes read (0 if the file is atEnd)"

	| result |
	self mustBeReading.
	result := self dll
		unzReadCurrentFile: self asParameter
		buffer: byteObject
		size: byteObject size.
	(result between: 0 and: byteObject size)
	ifFalse: [
		result = ZUnzParamerror ifTrue: [ ^self error: 'Parameter error. Must open the file first.' ].
		result = ZUnzBadzipfile ifTrue: [ ^self error: 'Bad zip file.' ].
		result = ZipInternalerror ifTrue: [ ^self error: 'ZipInternal error.' ].
		result = ZUnzCrcerror ifTrue: [ ^self error: 'CRC error.' ].
		^self error: 'Can''t read from zipped file.'
	].
	^result!   
checkMode: aSymbol
	" Private - check that the receiver is in mode aSymbol. "

	self mode = aSymbol ifFalse: [
		self error: 'Invalid Open mode.'
	].!   
locateFile: fileName
	"Try locate the file fileName in the receiver.
	Returns true if success and position the receiver at this file."

	^self locateFile: fileName caseSensitivity: false!   
pathName
    "Returns the instance var of the receiver
     for external manipulation"
    ^pathName!  
getFileContents: fileName
	"Try locate the file fileName in the receiver and extract it's contents.
	Returns the contents in a string if success. Else returns nil."

	(self locateFile: fileName)
	ifTrue: [ ^self getCurrentFileContents ].
	^nil!
openWrite: aPathName append: append
	"Returns true if the receiver can open the zip file pathName
	to be written. If append is true, the zip file will be created
     from eof of the existing file named aPathName
	 (it is used to create self extractor files)"

	self close.
	handle := self dll
		zipOpen: aPathName asParameter
		append: append asParameter.
	handle = 0 ifTrue: [
		( (aPathName includes: $.) not
		and: [self class extension size > 0])
		ifTrue: [
			^self openWrite: aPathName,'.',self class extension append: append
		].
		^false
	].
	pathName := aPathName.
	mode := #write.
	^true!  
mustBeReading
	"The receiver must be in read mode."

	self checkMode: #read!   
newZipFileInfo
	"Private - Returns a new zip file info structure with the current dateTime settings."

	| zipFileInfo |
	zipFileInfo := self dll structureNamed: 'zip_fileinfo'.
	"TODO: must be implemented."
	^zipFileInfo!   
mode
    "Returns the instance var of the receiver
     for external manipulation"
    ^mode!  
closeCurrentFile
	"Close the current file."

	^self closeFile! 
write: byteObject
	"Write byteObject onto the created file."

	| result |
	self mustBeWriting.
	result := self dll
		zipWriteInFileInZip: self asParameter
		buffer: byteObject
		length: byteObject size.
	result = ZipOk ifTrue: [ ^true ].

	result = ZUnzParamerror ifTrue: [ ^self error: 'Parameter error. Must create the file first.' ].
	result = ZipInternalerror ifTrue: [ ^self error: 'ZipInternal error.' ].
	^self error: 'Can''t write tozipped file.'!  
isValid
	"True if the receiver is valid."

	^handle notNil and: [handle ~~ 0]! 
write: byteObject as: fileName
	"Write byteObject onto a new created file named fileName."

	self
		createFile: fileName;
		write: byteObject;
		closeCurrentFile!  
close
	"Close the receiver."

	self isValid ifTrue: [
		self mode = #read
		ifTrue: [ self dll unzClose: self asParameter ]
		ifFalse: [ self dll zipClose: self asParameter ].
	].
	handle := nil.!  
withAllFileInfosAndNamesDo: aBlock
	"Evaluates aBlock with all the receiver's fileInfos and names."

	| count array |
	self mustBeReading.
	count := self numberOfEntries.
	(self dll unzGoToFirstFile: self asParameter) = UnzOk
	ifFalse: [ self error: 'Can''t locate first file information.' ].

	1 to: count do: [:index|
		array := self getCurrentFileInfoAndFileName.
		aBlock value: array first value: array last.

		index < count
		ifTrue: [
			(self dll unzGoToNextFile: self asParameter) = UnzOk
			ifFalse: [ self error: 'Can''t locate #',index asString,' file information.' ].
		].
	].! 
numberOfEntries
	"Returns the number of entries in the receiver."

	^self globalInfo numberEntry!  
createFile: fileName comment: comment method: method level: level
	"Open the current file."

	| zipInfo |
	self mustBeWriting.
	zipInfo := self newZipFileInfo.
	^UnzOk = (self dll
		zipOpenNewFileInZip: self asParameter
		fileName: fileName
		zipInfo: zipInfo
		local: nil localSize: 0
		global: nil globalSize: 0
		comment: comment asParameter
		method: method asParameter
		level: level asParameter)!  
mustBeWriting
	"The receiver must be in write mode."

	self checkMode: #write! 
contentsOf: fileName
	"Try locate the file fileName in the receiver and extract it's contents.
	Returns the contents in a string if success. Else returns nil."

	^self getFileContents: fileName!
reOpen
	"ReOpen the receiver."

	^self open: self pathName!
getCurrentFileContents
	"Returns the current file contents in aString."

	| read buffer array |
	array := self getCurrentFileInfoAndFileName.
	buffer := String new: array first uncompressedSize.
	self openCurrentFile.
	self readCurrentFileInto: buffer.
	self closeCurrentFile.
	^buffer
	!
dll
	"Returns the receiver's dynamic link library"

	^ZLibDLL library! 
fileName
        "Answer the receiver's file name."

    ^'zLib.dll'!  
initializeConstants
	" Private - Initializes the ZLib constants.
		ZLibDLL initializeConstants
	"

	ZLibConstants isNil ifTrue: [
		ZLibConstants := Dictionary new.
	].
	ZLibConstants
		at: 'ZlibVersion' put: '1.1.3';
		at: 'ZNoFlush' put: 0;
		at: 'ZPartialFlush' put: 1;
		at: 'ZSyncFlush' put: 2;
		at: 'ZFullFlush' put: 3;
		at: 'ZFinish' put: 4;

		at: 'ZOk' put: 0;
		at: 'ZStreamEnd' put: 1;
		at: 'ZNeedDict' put: 2;
		at: 'ZErrno' put: -1;
		at: 'ZStreamError' put: -2;
		at: 'ZDataError' put: -3;
		at: 'ZMemError' put: -4;
		at: 'ZBufError' put: -5;
		at: 'ZVersionError' put: -6;

		at: 'ZNoCompression' put: 0;
		at: 'ZBestSpeed' put: 1;
		at: 'ZBestCompression' put: 9;
		at: 'ZDefaultCompression' put: -1;

		at: 'ZFiltered' put: 1;
		at: 'ZHuffmanOnly' put: 2;
		at: 'ZDefaultStrategy' put: 0;

		at: 'ZBinary' put: 0;
		at: 'ZAscii' put: 1;
		at: 'ZUnknown' put: 2;

		at: 'ZDeflated' put: 8;
		at: 'ZNull' put: 0;

	"ZIP constants"
		at: 'ZipOk' put: 0;
		at: 'ZipErrno' put: (ZLibConstants at: 'ZErrno');
		at: 'ZipParamerror' put: -102;
		at: 'ZipInternalerror' put: -104;

	"UNZIP constants"
		at: 'UnzOk' put: 0;
		at: 'UnzEndOfListOfFile' put: -100;
		at: 'UnzErrno' put: (ZLibConstants at: 'ZErrno');
		at: 'UnzEof' put: 0;
		at: 'ZUnzParamerror' put: -102;
		at: 'ZUnzBadzipfile' put: -103;
		at: 'ZipInternalerror' put: -104;
		at: 'ZUnzCrcerror' put: -105;

		yourself!
initializeStructures
    "Private - Initializes the structures for the interfase.
    ZLibDLL initializeStructures
    "

    self
        registerType: 'z_stream'
        as:#(
            (nextIn ulong asExternalAddress) "next input byte"
            (availIn ulong) "number of bytes available at nextIn"
            (totalIn ulong)  "total nb of input bytes read so far"

            (nextOut ulong)  "next output byte should be put there"
            (availOut ulong)  "remaining free space at nextOut"
            (totalOut ulong)  "total nb of bytes output so far "

            (msg ulong asCString)  "last error message, NULL if no error"
			(state ulong) "not visible by applications"

			(zalloc ulong) "used to allocate the internal state"
			(zfree ulong) "used to free the internal state"
			(opaque ulong) "private data object passed to zalloc and zfree"

			(dataType long) "best guess about the data type: ascii or binary"
			(adler ulong) "adler32 value of the uncompressed data"
			(reserved ulong) "reserved for future use"
        );
        registerType: 'tm_zip'
        as:#(
			(seconds ulong) "seconds after the minute - [0,59]"
			(minutes ulong) "minutes after the hour - [0,59]"
			(hours ulong) "hours since midnight - [0,23]"
			(day ulong) "day of the month - [1,31]]"
			(months ulong) "months since January - [0,11]"
			(years ulong) "years - [1980..2044]"
        );
        registerType: 'zip_fileinfo'
        as:#(
			(date 'tm_zip') "date in understandable format"
			(dosDate ulong) "if dos_date == 0, tmu_date is used"
			(internalFileAttribute ulong) "internal file attributes        2 bytes"
			(externalFileAttribute ulong) "external file attributes      4 bytes"
        );
        registerType: 'unz_global_info'
        as:#(
			(numberEntry ulong) "total number of entries in the central dir on this disk"
			(sizeComment ulong) "size of the global comment of the zipfile"
        );
        registerType: 'unz_file_info'
        as:#(
			(version ulong) "version made by. 2 bytes"
			(versionNeeded ulong) "version needed to extract. 2 bytes"
			(flag ulong) "general purpose bit flag. 2 bytes"
			(compressionMethod ulong) "compression method. 2 bytes"
			(dosDate ulong) "last mod file date in Dos fmt. 4 bytes"
			(crc ulong) "crc-32                          4 bytes"
			(compressedSize ulong) "compressed size                 4 bytes"
			(uncompressedSize ulong) "uncompressed size               4 bytes"
			(sizeFilename ulong) "filename length                 2 bytes"
			(sizeFileExtra ulong) "extra field length              2 bytes"
			(sizeFileComment ulong) "file comment length             2 bytes"
			(diskNumberStart ulong) "disk number start               2 bytes"
			(internalFileAttributes ulong) "internal file attributes        2 bytes"
			(externalFileAttributes ulong) "external file attributes        4 bytes"
			(date 'tm_zip') "date in understandable format"
		);
        yourself.!  
zipClose: zipFile comment: comment
	"
	Close the zipfile.

	extern int ZEXPORT zipClose OF((zipFile file,
                const char* global_comment));
	"

    <api: zipClose long struct long>
    ^self invalidArgument!  
zipOpen: pathName append: append
	"
	Create a zipfile.
     pathname contain on Windows NT a filename like 'c:\zlib\zlib111.zip'
	 or on an Unix computer 'zlib/zlib111.zip'.
     if the file pathname exist and append=1, the zip will be created
	 at the end of the file. (useful if the file contain a self extractor code)
     If the zipfile cannot be opened, the return value is NULL.
     Else, the return value is a zipFile Handle, usable with other function
       of this zip package.

	extern zipFile ZEXPORT zipOpen OF((const char *pathname, int append));
	"

    <api: zipOpen struct long ulongReturn>
    ^self invalidArgument!
unztell: zipFile
	"
	Give the current position in uncompressed data.

	extern z_off_t ZEXPORT unztell OF((unzFile file));
	"

    <api: unztell long ulongReturn>
    ^self invalidArgument!  
unzGetCurrentFileInfo: file
	info: info
	filename: fileName fileNameSize: fileNameSize
	extraField: extraFiled extraSize: extraSize
	comment: comment commentSize: commentSize
	"
	Get Info about the current file
  if pfile_info!!=NULL, the *pfile_info structure will contain somes info about the current file
  if szFileName!!=NULL, the filemane string will be copied in szFileName (fileNameBufferSize is the size of the buffer)
  if extraField!!=NULL, the extra field information will be copied in extraField (extraFieldBufferSize is the size of the buffer).
            This is the Central-header version of the extra field
  if szComment!!=NULL, the comment string of the file will be copied in szComment
            (commentBufferSize is the size of the buffer)

	extern int ZEXPORT unzGetCurrentFileInfo OF((unzFile file,
                         unz_file_info *pfile_info,
                         char *szFileName,
                         uLong fileNameBufferSize,
                         void *extraField,
                         uLong extraFieldBufferSize,
                         char *szComment,
                         uLong commentBufferSize));
	"

    <api: unzGetCurrentFileInfo long struct struct ulong struct ulong struct ulong long>
    ^self invalidArgument!
gzeof: file
	"
	Returns 1 when EOF has previously been detected reading the given
   input stream, otherwise zero.

	ZEXTERN int ZEXPORT gzeof OF((gzFile file));
	"

    <api: gzeof long long>
    ^self invalidArgument!  
zipWriteInFileInZip: zipFile buffer: buffer length: length
	"
	Write data in the zipfile

	extern int ZEXPORT zipWriteInFileInZip OF((zipFile file,
                       const voidp buf,
                       unsigned len));
	"

    <api: zipWriteInFileInZip long struct ulong long>
    ^self invalidArgument! 
gzclose: file
	"
	Flushes all pending output if necessary, closes the compressed file
   and deallocates all the (de)compression state. The return value is the zlib
   error number (see function gzerror below).

	ZEXTERN int ZEXPORT    gzclose OF((gzFile file));
	"

    <api: gzclose long long>
    ^self invalidArgument!  
inflateSync: stream
	"
	Skips invalid compressed data until a full flush point (see above the
  description of deflate with Z_FULL_FLUSH) can be found, or until all
  available input is skipped. No output is provided.

    inflateSync returns Z_OK if a full flush point has been found, Z_BUF_ERROR
  if no more input was provided, Z_DATA_ERROR if no flush point has been found,
  or Z_STREAM_ERROR if the stream structure was inconsistent. In the success
  case, the application may save the current current value of total_in which
  indicates where valid compressed data was found. In the error case, the
  application may repeatedly call inflateSync, providing more input each time,
  until success or end of the input data.

	ZEXTERN int ZEXPORT inflateSync OF((z_streamp strm));
	"

    <api: inflateSync struct long>
    ^self invalidArgument!
gzopen: path mode: mode
	"
	Opens a gzip (.gz) file for reading or writing. The mode parameter
   is as in fopen ('rb' or 'wb') but can also include a compression level
   ('wb9') or a strategy: 'f' for filtered data as in wb6f, 'h' for
   Huffman only compression as in wb1h. (See the description
   of deflateInit2 for more information about the strategy parameter.)

     gzopen can be used to read a file which is not in gzip format; in this
   case gzread will directly read from the file without decompression.

     gzopen returns NULL if the file could not be opened or if there was
   insufficient memory to allocate the (de)compression state; errno
   can be checked to distinguish the two cases (if errno is zero, the
   zlib error is Z_MEM_ERROR).

	ZEXTERN gzFile ZEXPORT gzopen  OF((const char *path, const char *mode));
	"

    <api: gzopen struct struct ulongReturn>
    ^self invalidArgument! 
gzputs: file buffer: buffer
	"
	Writes the given null-terminated string to the compressed file,
	 excluding the terminating null character.
    gzputs returns the number of characters written,
	 or -1 in case of error.

	ZEXTERN int ZEXPORT gzputs OF((gzFile file, const char *s));
	"

    <api: gzputs long struct long>
    ^self invalidArgument!
gzprintf: file format: format value: value
	"
	Converts, formats, and writes the args to the compressed file under
   control of the format string, as in fprintf. gzprintf returns the number of
   uncompressed bytes actually written (0 in case of error).

	ZEXTERN int ZEXPORTVA   gzprintf OF((gzFile file, const char *format, ...));
	"

    <api: gzprintf long struct struct long>
    ^self invalidArgument!
deflate: stream flush: flush
	"
	Deflate compresses as much data as possible, and stops when the input
  buffer becomes empty or the output buffer becomes full. It may introduce some
  output latency (reading input without producing any output) except when
  forced to flush.

    The detailed semantics are as follows. deflate performs one or both of the
  following actions:

  - Compress more input starting at next_in and update next_in and avail_in
    accordingly. If not all input can be processed (because there is not
    enough room in the output buffer), next_in and avail_in are updated and
    processing will resume at this point for the next call of deflate().

  - Provide more output starting at next_out and update next_out and avail_out
    accordingly. This action is forced if the parameter flush is non zero.
    Forcing flush frequently degrades the compression ratio, so this parameter
    should be set only when necessary (in interactive applications).
    Some output may be provided even if flush is not set.

  Before the call of deflate(), the application should ensure that at least
  one of the actions is possible, by providing more input and/or consuming
  more output, and updating avail_in or avail_out accordingly; avail_out
  should never be zero before the call. The application can consume the
  compressed output when it wants, for example when the output buffer is full
  (avail_out == 0), or after each call of deflate(). If deflate returns Z_OK
  and with zero avail_out, it must be called again after making room in the
  output buffer because there might be more output pending.

    If the parameter flush is set to Z_SYNC_FLUSH, all pending output is
  flushed to the output buffer and the output is aligned on a byte boundary, so
  that the decompressor can get all input data available so far. (In particular
  avail_in is zero after the call if enough output space has been provided
  before the call.)  Flushing may degrade compression for some compression
  algorithms and so it should be used only when necessary.

    If flush is set to Z_FULL_FLUSH, all output is flushed as with
  Z_SYNC_FLUSH, and the compression state is reset so that decompression can
  restart from this point if previous compressed data has been damaged or if
  random access is desired. Using Z_FULL_FLUSH too often can seriously degrade
  the compression.

    If deflate returns with avail_out == 0, this function must be called again
  with the same value of the flush parameter and more output space (updated
  avail_out), until the flush is complete (deflate returns with non-zero
  avail_out).

    If the parameter flush is set to Z_FINISH, pending input is processed,
  pending output is flushed and deflate returns with Z_STREAM_END if there
  was enough output space; if deflate returns with Z_OK, this function must be
  called again with Z_FINISH and more output space (updated avail_out) but no
  more input data, until it returns with Z_STREAM_END or an error. After
  deflate has returned Z_STREAM_END, the only possible operations on the
  stream are deflateReset or deflateEnd.

    Z_FINISH can be used immediately after deflateInit if all the compression
  is to be done in a single step. In this case, avail_out must be at least
  0.1% larger than avail_in plus 12 bytes.  If deflate does not return
  Z_STREAM_END, then it must be called again as described above.

    deflate() sets strm->adler to the adler32 checksum of all input read
  so far (that is, total_in bytes).

    deflate() may update data_type if it can make a good guess about
  the input data type (Z_ASCII or Z_BINARY). In doubt, the data is considered
  binary. This field is only for information purposes and does not affect
  the compression algorithm in any manner.

    deflate() returns Z_OK if some progress has been made (more input
  processed or more output produced), Z_STREAM_END if all input has been
  consumed and all output has been produced (only when flush is set to
  Z_FINISH), Z_STREAM_ERROR if the stream state was inconsistent (for example
  if next_in or next_out was NULL), Z_BUF_ERROR if no progress is possible
  (for example avail_in or avail_out was zero).


	ZEXTERN int ZEXPORT deflate OF((z_streamp strm, int flush));
	"

    <api: deflate struct long long>
    ^self invalidArgument!
adler: adler buffer: bufPtr length: length
	"Update a running Adler-32 checksum with the bytes buf[0..len-1]
	and return the updated checksum. If buf is NULL, this function returns
	the required initial value for the checksum.
	An Adler-32 checksum is almost as reliable as a CRC32 but can be
	 computed much faster.
	Usage example:
	     uLong adler = adler32(0L, Z_NULL, 0);
	     while (read_buffer(buffer, length) !!= EOF) {
    	   adler = adler32(adler, buffer, length);
	     }
    	 if (adler !!= original_adler) error();

	ZEXTERN uLong ZEXPORT adler32 OF((uLong adler, const Bytef *buf, uInt len));
	"

    <api: adler32 ulong struct ulong ulong>
    ^self invalidArgument!  
inflateInit: stream
	"
	Initializes the internal stream state for decompression. The fields
   next_in, avail_in, zalloc, zfree and opaque must be initialized before by
   the caller. If next_in is not Z_NULL and avail_in is large enough (the exact
   value depends on the compression method), inflateInit determines the
   compression method from the zlib header and allocates all data structures
   accordingly; otherwise the allocation will be deferred to the first call of
   inflate.  If zalloc and zfree are set to Z_NULL, inflateInit updates them to
   use default allocation functions.

     inflateInit returns Z_OK if success, Z_MEM_ERROR if there was not enough
   memory, Z_VERSION_ERROR if the zlib library version is incompatible with the
   version assumed by the caller.  msg is set to null if there is no error
   message. inflateInit does not perform any decompression apart from reading
   the zlib header if present: this will be done by inflate().  (So next_in and
   avail_in may be modified, but next_out and avail_out are unchanged.)

	ZEXTERN int ZEXPORT inflateInit OF((z_streamp strm));
	"

    <api: inflateInit struct long>
    ^self invalidArgument! 
crc32: crc buffer: bufPtr length: length
	"
	Update a running crc with the bytes buf[0..len-1] and return the updated
   crc. If buf is NULL, this function returns the required initial value
   for the crc. Pre- and post-conditioning (one's complement) is performed
   within this function so it shouldn't be done by the application.
   Usage example:

     uLong crc = crc32(0L, Z_NULL, 0);

     while (read_buffer(buffer, length) !!= EOF) {
       crc = crc32(crc, buffer, length);
     }
     if (crc !!= original_crc) error();

	ZEXTERN uLong ZEXPORT crc32   OF((uLong crc, const Bytef *buf, uInt len));
	"

    <api: crc32 ulong struct ulong ulong>
    ^self invalidArgument!  
inflate: stream flush: flush
	"
	Inflate decompresses as much data as possible, and stops when the input
  buffer becomes empty or the output buffer becomes full. It may some
  introduce some output latency (reading input without producing any output)
  except when forced to flush.

  The detailed semantics are as follows. inflate performs one or both of the
  following actions:

  - Decompress more input starting at next_in and update next_in and avail_in
    accordingly. If not all input can be processed (because there is not
    enough room in the output buffer), next_in is updated and processing
    will resume at this point for the next call of inflate().

  - Provide more output starting at next_out and update next_out and avail_out
    accordingly.  inflate() provides as much output as possible, until there
    is no more input data or no more space in the output buffer (see below
    about the flush parameter).

  Before the call of inflate(), the application should ensure that at least
  one of the actions is possible, by providing more input and/or consuming
  more output, and updating the next_* and avail_* values accordingly.
  The application can consume the uncompressed output when it wants, for
  example when the output buffer is full (avail_out == 0), or after each
  call of inflate(). If inflate returns Z_OK and with zero avail_out, it
  must be called again after making room in the output buffer because there
  might be more output pending.

    If the parameter flush is set to Z_SYNC_FLUSH, inflate flushes as much
  output as possible to the output buffer. The flushing behavior of inflate is
  not specified for values of the flush parameter other than Z_SYNC_FLUSH
  and Z_FINISH, but the current implementation actually flushes as much output
  as possible anyway.

    inflate() should normally be called until it returns Z_STREAM_END or an
  error. However if all decompression is to be performed in a single step
  (a single call of inflate), the parameter flush should be set to
  Z_FINISH. In this case all pending input is processed and all pending
  output is flushed; avail_out must be large enough to hold all the
  uncompressed data. (The size of the uncompressed data may have been saved
  by the compressor for this purpose.) The next operation on this stream must
  be inflateEnd to deallocate the decompression state. The use of Z_FINISH
  is never required, but can be used to inform inflate that a faster routine
  may be used for the single inflate() call.

     If a preset dictionary is needed at this point (see inflateSetDictionary
  below), inflate sets strm-adler to the adler32 checksum of the
  dictionary chosen by the compressor and returns Z_NEED_DICT; otherwise
  it sets strm->adler to the adler32 checksum of all output produced
  so far (that is, total_out bytes) and returns Z_OK, Z_STREAM_END or
  an error code as described below. At the end of the stream, inflate()
  checks that its computed adler32 checksum is equal to that saved by the
  compressor and returns Z_STREAM_END only if the checksum is correct.

    inflate() returns Z_OK if some progress has been made (more input processed
  or more output produced), Z_STREAM_END if the end of the compressed data has
  been reached and all uncompressed output has been produced, Z_NEED_DICT if a
  preset dictionary is needed at this point, Z_DATA_ERROR if the input data was
  corrupted (input stream not conforming to the zlib format or incorrect
  adler32 checksum), Z_STREAM_ERROR if the stream structure was inconsistent
  (for example if next_in or next_out was NULL), Z_MEM_ERROR if there was not
  enough memory, Z_BUF_ERROR if no progress is possible or if there was not
  enough room in the output buffer when Z_FINISH is used. In the Z_DATA_ERROR
  case, the application may then call inflateSync to look for a good
  compression block.

	ZEXTERN int ZEXPORT inflate OF((z_streamp strm, int flush));
	"

    <api: inflate struct long long>
    ^self invalidArgument!
gzwrite: file buffer: buffer length: length
	"
	Writes the given number of uncompressed bytes into the compressed file.
   gzwrite returns the number of uncompressed bytes actually written
   (0 in case of error).

	ZEXTERN int ZEXPORT    gzwrite OF((gzFile file,
                   const voidp buf, unsigned len));
	"

    <api: gzwrite long struct long long>
    ^self invalidArgument!
compress: destination length: length source: source length: sourceLength
	"This function can be used to compress a whole file at once
	 if the input file is mapped.
	Compresses the source buffer into the destination buffer.
	Upon entry, length is the total size of the destination buffer,
	 which must be at least 0.1% larger than sourceLen plus 12 bytes.
	Upon exit, destLen is the actual size of the compressed buffer.
     compress returns
		Z_OK if success,
		Z_MEM_ERROR if there was not enough memory,
		Z_BUF_ERROR if there was not enough room in the output buffer.

	ZEXTERN int ZEXPORT compress OF((Bytef *dest,   uLongf *destLen,
                                 const Bytef *source, uLong sourceLen));
	"

    <api: compress struct ulong struct ulong ulong>
    ^self invalidArgument!  
gzflush: file flush: flush
	"
	Flushes all pending output into the compressed file. The parameter
   flush is as in the deflate() function. The return value is the zlib
   error number (see function gzerror below). gzflush returns Z_OK if
   the flush parameter is Z_FINISH and all output could be flushed.
     gzflush should be called only when strictly necessary because it can
   degrade compression.

	ZEXTERN int ZEXPORT    gzflush OF((gzFile file, int flush));
	"

    <api: gzflush long long long>
    ^self invalidArgument! 
unzOpen: pathName
	"
	Open a Zip file. path contain the full pathname (by example,
     on a Windows NT computer 'c:\zlib\zlib111.zip'
	 or on an Unix computer 'zlib/zlib111.zip'.
     If the zipfile cannot be opened (file don't exist or in not valid), the
       return value is NULL.
     Else, the return value is a unzFile Handle, usable with other function
       of this unzip package.

	extern unzFile ZEXPORT unzOpen OF((const char *path));
	"

    <api: unzOpen struct ulongReturn>
    ^self invalidArgument!   
zipCloseFileInZip: zipFile
	"
	Close the current file in the zipfile.

	extern int ZEXPORT zipCloseFileInZip OF((zipFile file));
	"

    <api: zipCloseFileInZip long long>
    ^self invalidArgument!
deflateReset: stream
	"
	This function is equivalent to deflateEnd followed by deflateInit,
   but does not free and reallocate all the internal compression state.
   The stream will keep the same compression level and any other attributes
   that may have been set by deflateInit2.

      deflateReset returns Z_OK if success, or Z_STREAM_ERROR if the source
   stream state was inconsistent (such as zalloc or state being NULL).

	ZEXTERN int ZEXPORT deflateReset OF((z_streamp strm));
	"

    <api: deflateReset struct long>
    ^self invalidArgument!  
unzCloseCurrentFile: zipFile
	"
	Close the file in zip opened with unzOpenCurrentFile
  Return UNZ_CRCERROR if all the file was read but the CRC is not good

	extern int ZEXPORT unzCloseCurrentFile OF((unzFile file));
	"

    <api: unzCloseCurrentFile long long>
    ^self invalidArgument!
unzGetLocalExtrafield: zipFile buffer: buffer length: length
	"
	Read extra field from the current file (opened by unzOpenCurrentFile)
  This is the local-header version of the extra field (sometimes, there is
    more info in the local-header version than in the central-header)

  if buf==NULL, it return the size of the local extra field

  if buf!!=NULL, len is the size of the buffer, the extra header is copied in
    buf.
  the return value is the number of bytes copied in buf, or (if <0)
    the error code

	extern int ZEXPORT unzGetLocalExtrafield OF((unzFile file,
                                             voidp buf, unsigned len));
	"

    <api: unzGetLocalExtrafield long struct ulong boolean>
    ^self invalidArgument!  
gzgetc: file
	"
	Reads one byte from the compressed file. gzgetc returns this byte
   or -1 in case of end of file or error.

	ZEXTERN int ZEXPORT    gzgetc OF((gzFile file));
	"

    <api: gzgetc long long>
    ^self invalidArgument!   
gzsetparams: file level: level strategy: strategy
	"
	Dynamically update the compression level or strategy. See the description
   of deflateInit2 for the meaning of these parameters.
     gzsetparams returns Z_OK if success, or Z_STREAM_ERROR if the file was not
   opened for writing.

	ZEXTERN int ZEXPORT gzsetparams OF((gzFile file, int level, int strategy));
	"

    <api: gzsetparams long long long long>
    ^self invalidArgument! 
gztell: file
	"
	Returns the starting position for the next gzread or gzwrite on the
   given compressed file. This position represents a number of bytes in the
   uncompressed data stream.

   gztell(file) is equivalent to gzseek(file, 0L, SEEK_CUR)

	ZEXTERN z_off_t ZEXPORT    gztell OF((gzFile file));
	"

    <api: gztell long long>
    ^self invalidArgument!  
inflateReset: stream
	"
	This function is equivalent to inflateEnd followed by inflateInit,
   but does not free and reallocate all the internal decompression state.
   The stream will keep attributes that may have been set by inflateInit2.

      inflateReset returns Z_OK if success, or Z_STREAM_ERROR if the source
   stream state was inconsistent (such as zalloc or state being NULL).

	ZEXTERN int ZEXPORT inflateReset OF((z_streamp strm));
	"

    <api: inflateReset struct long>
    ^self invalidArgument! 
gzgets: file buffer: buffer length: length
	"
	Reads bytes from the compressed file until len-1 characters are read, or
   a newline character is read and transferred to buf, or an end-of-file
   condition is encountered.  The string is then terminated with a null
   character.
      gzgets returns buf, or Z_NULL in case of error.

	ZEXTERN char * ZEXPORT gzgets OF((gzFile file, char *buf, int len));
	"

    <api: gzgets long struct long ulongReturn>
    ^self invalidArgument! 
gzread: file buffer: buffer length: length
	"
	Reads the given number of uncompressed bytes from the compressed file.
   If the input file was not in gzip format, gzread copies the given number
   of bytes into the buffer.
     gzread returns the number of uncompressed bytes actually read (0 for
   end of file, -1 for error).

	ZEXTERN int ZEXPORT    gzread  OF((gzFile file, voidp buf, unsigned len));
	"

    <api: gzread long struct long long>
    ^self invalidArgument!   
unzLocateFile: zipFile fileName: fileName caseSensitivity: caseSensitivity
	"
	Try locate the file szFileName in the zipfile.
  For the iCaseSensitivity signification, see unzStringFileNameCompare

  return value :
  UNZ_OK if the file is found. It becomes the current file.
  UNZ_END_OF_LIST_OF_FILE if the file is not found

	extern int ZEXPORT unzLocateFile OF((unzFile file,
                     const char *szFileName,
                     int iCaseSensitivity));
	"

    <api: unzLocateFile long struct long long>
    ^self invalidArgument! 
unzeof: zipFile
	"
	return 1 if the end of file was reached, 0 elsewhere 

	extern int ZEXPORT unzeof OF((unzFile file));
	"

    <api: unzeof long boolean>
    ^self invalidArgument!   
unzGetGlobalComment: zipFile comment: comment size: size
	"
	Get the global comment string of the ZipFile, in the szComment buffer.
  uSizeBuf is the size of the szComment buffer.
  return the number of byte copied or an error code <0

	extern int ZEXPORT unzGetGlobalComment OF((unzFile file,
                                           char *szComment, uLong uSizeBuf));
	"

    <api: unzGetGlobalComment long struct ulong long>
    ^self invalidArgument!   
gzputc: file integer: integer
	"
	Writes c, converted to an unsigned char, into the compressed file.
   gzputc returns the value that was written, or -1 in case of error.

	ZEXTERN int ZEXPORT    gzputc OF((gzFile file, int c));
	"

    <api: gzputc long long long>
    ^self invalidArgument! 
unzGetCurrentFileInfo: file
	info: info
	filename: fileName
	fileNameSize: fileNameSize
	" Get Info about the current file. "

    ^self 
			unzGetCurrentFileInfo: file
			info: info
			filename: fileName fileNameSize: fileNameSize
			extraField: nil extraSize: 0
			comment: nil commentSize: 0!
deflateParams: stream level: level strategy: strategy
	"
	Dynamically update the compression level and compression strategy.  The
   interpretation of level and strategy is as in deflateInit2.  This can be
   used to switch between compression and straight copy of the input data, or
   to switch to a different kind of input data requiring a different
   strategy. If the compression level is changed, the input available so far
   is compressed with the old level (and may be flushed); the new level will
   take effect only at the next call of deflate().

     Before the call of deflateParams, the stream state must be set as for
   a call of deflate(), since the currently available input may have to
   be compressed and flushed. In particular, strm->avail_out must be non-zero.

     deflateParams returns Z_OK if success, Z_STREAM_ERROR if the source
   stream state was inconsistent or if a parameter was invalid, Z_BUF_ERROR
   if strm->avail_out was zero.

	ZEXTERN int ZEXPORT deflateParams OF((z_streamp strm,
                      int level,
                      int strategy));

	"

    <api: deflateParams struct long long long>
    ^self invalidArgument! 
unzGoToFirstFile: zipFile
	"
	Set the current file of the zipfile to the first file.
  return UNZ_OK if there is no problem

	extern int ZEXPORT unzGoToFirstFile OF((unzFile file));
	"

    <api: unzGoToFirstFile long long>
    ^self invalidArgument!   
unzReadCurrentFile: zipFile buffer: buffer size: size
	"
	Read bytes from the current file (opened by unzOpenCurrentFile)
  buf contain buffer where data must be copied
  len the size of buf.

  return the number of byte copied if somes bytes are copied
  return 0 if the end of file was reached
  return <0 with error code if there is an error
    (UNZ_ERRNO for IO error, or zLib error for uncompress error)

	extern int ZEXPORT unzReadCurrentFile OF((unzFile file,
                      voidp buf, unsigned len));
	"

    <api: unzReadCurrentFile long struct ulong long>
    ^self invalidArgument!  
gzdopen: descriptor mode: mode
	"
	gzdopen() associates a gzFile with the file descriptor fd.  File
   descriptors are obtained from calls like open, dup, creat, pipe or
   fileno (in the file has been previously opened with fopen).
   The mode parameter is as in gzopen.
     The next call of gzclose on the returned gzFile will also close the
   file descriptor fd, just like fclose(fdopen(fd), mode) closes the file
   descriptor fd. If you want to keep fd open, use gzdopen(dup(fd), mode).
     gzdopen returns NULL if there was insufficient memory to allocate
   the (de)compression state.

	ZEXTERN gzFile ZEXPORT gzdopen  OF((int fd, const char *mode));
	"

    <api: gzdopen long struct ulongReturn>
    ^self invalidArgument!
deflateCopy: destination source: source
	"
	Sets the destination stream as a complete copy of the source stream.

     This function can be useful when several compression strategies will be
   tried, for example when there are several ways of pre-processing the input
   data with a filter. The streams that will be discarded should then be freed
   by calling deflateEnd.  Note that deflateCopy duplicates the internal
   compression state which can be quite large, so this strategy is slow and
   can consume lots of memory.

     deflateCopy returns Z_OK if success, Z_MEM_ERROR if there was not
   enough memory, Z_STREAM_ERROR if the source stream state was inconsistent
   (such as zalloc being NULL). msg is left unchanged in both source and
   destination.

	ZEXTERN int ZEXPORT deflateCopy OF((z_streamp dest,
                                    z_streamp source));

	"

    <api: deflateCopy struct struct long>
    ^self invalidArgument!   
uncompress: destination length: length source: source length: sourceLength
	"
	Decompresses the source buffer into the destination buffer.  sourceLen is
   the byte length of the source buffer. Upon entry, destLen is the total
   size of the destination buffer, which must be large enough to hold the
   entire uncompressed data. (The size of the uncompressed data must have
   been saved previously by the compressor and transmitted to the decompressor
   by some mechanism outside the scope of this compression library.)
   Upon exit, destLen is the actual size of the compressed buffer.
     This function can be used to decompress a whole file at once if the
   input file is mmap'ed.

     uncompress returns Z_OK if success, Z_MEM_ERROR if there was not
   enough memory, Z_BUF_ERROR if there was not enough room in the output
   buffer, or Z_DATA_ERROR if the input data was corrupted.

	ZEXTERN int ZEXPORT uncompress OF((Bytef *dest,   uLongf *destLen,
                                   const Bytef *source, uLong sourceLen));
	"

    <api: uncompress struct ulong struct ulong ulong>
    ^self invalidArgument!
unzClose: zipFile
	"
	Close a ZipFile opened with unzipOpen.
  If there is files inside the .Zip opened with unzOpenCurrentFile (see later),
    these files MUST be closed with unzipCloseCurrentFile before call unzipClose.
  return UNZ_OK if there is no problem.

	extern int ZEXPORT unzClose OF((unzFile file));
	"

    <api: unzClose long long>
    ^self invalidArgument!  
zipOpenNewFileInZip: zipFile
	fileName: fileName
	zipInfo: zipInfo
	local: local localSize: localSize
	global: global globalSize: globalSize
	comment: comment
	method: method
	level: level
	"
	Open a file in the ZIP for writing.
  filename : the filename in zip (if NULL, '-' without quote will be used
  *zipfi contain supplemental information
  if extrafield_local!!=NULL and size_extrafield_local>0, extrafield_local
    contains the extrafield data the the local header
  if extrafield_global!!=NULL and size_extrafield_global>0, extrafield_global
    contains the extrafield data the the local header
  if comment !!= NULL, comment contain the comment string
  method contain the compression method (0 for store, Z_DEFLATED for deflate)
  level contain the level of compression (can be Z_DEFAULT_COMPRESSION)

	extern int ZEXPORT zipOpenNewFileInZip OF((zipFile file,
                       const char* filename,
                       const zip_fileinfo* zipfi,
                       const void* extrafield_local,
                       uInt size_extrafield_local,
                       const void* extrafield_global,
                       uInt size_extrafield_global,
                       const char* comment,
                       int method,
                       int level));
	"

    <api: zipOpenNewFileInZip long struct struct struct ulong struct ulong struct long long long>
    ^self invalidArgument!
zipClose: zipFile
	"Close the zipfile."

    ^self zipClose: zipFile comment: nil! 
unzStringFileNameCompare: fileName1 with: fileName2 caseSensitivity: caseSensitivity
	"
	Compare two filename (fileName1,fileName2).
   If iCaseSenisivity = 1, comparision is case sensitivity (like strcmp)
   If iCaseSenisivity = 2, comparision is not case sensitivity (like strcmpi
                                or strcasecmp)
   If iCaseSenisivity = 0, case sensitivity is defaut of your operating system
    (like 1 on Unix, 2 on Windows)

	extern int ZEXPORT unzStringFileNameCompare OF ((const char* fileName1,
                                                 const char* fileName2,
                                                 int iCaseSensitivity));
	"

    <api: unzStringFileNameCompare struct struct long long>
    ^self invalidArgument!  
gzseek: file offset: offset whence: whence
	"
	Sets the starting position for the next gzread or gzwrite on the
   given compressed file. The offset represents a number of bytes in the
   uncompressed data stream. The whence parameter is defined as in lseek(2);
   the value SEEK_END is not supported.
     If the file is opened for reading, this function is emulated but can be
   extremely slow. If the file is opened for writing, only forward seeks are
   supported; gzseek then compresses a sequence of zeroes up to the new
   starting position.

      gzseek returns the resulting offset location as measured in bytes from
   the beginning of the uncompressed stream, or -1 in case of error, in
   particular if the file is opened for writing and the new starting position
   would be before the current position.

	ZEXTERN z_off_t ZEXPORT    gzseek OF((gzFile file,
                      z_off_t offset, int whence));
	"

    <api: gzseek struct long long long>
    ^self invalidArgument!   
deflateEnd: stream
	"
	All dynamically allocated data structures for this stream are freed.
   This function discards any unprocessed input and does not flush any
   pending output.

     deflateEnd returns Z_OK if success, Z_STREAM_ERROR if the
   stream state was inconsistent, Z_DATA_ERROR if the stream was freed
   prematurely (some input or output was discarded). In the error case,
   msg may be set but then points to a static string (which must not be
   deallocated).

	ZEXTERN int ZEXPORT deflateEnd OF((z_streamp strm));
	"

    <api: deflateEnd struct long>
    ^self invalidArgument! 
inflateEnd: stream
	"
	All dynamically allocated data structures for this stream are freed.
   This function discards any unprocessed input and does not flush any
   pending output.

     inflateEnd returns Z_OK if success, Z_STREAM_ERROR if the stream state
   was inconsistent. In the error case, msg may be set but then points to a
   static string (which must not be deallocated).

	ZEXTERN int ZEXPORT inflateEnd OF((z_streamp strm));
	"

    <api: inflateEnd struct long>
    ^self invalidArgument!
unzOpenCurrentFile: zipFile
	"
	Open for reading data the current file in the zipfile.
  If there is no error, the return value is UNZ_OK.

	extern int ZEXPORT unzOpenCurrentFile OF((unzFile file));
	"

    <api: unzOpenCurrentFile long long>
    ^self invalidArgument!
compress: destination length: length source: source length: sourceLength level: level
	"
	Compresses the source buffer into the destination buffer. The level
   parameter has the same meaning as in deflateInit.  sourceLen is the byte
   length of the source buffer. Upon entry, destLen is the total size of the
   destination buffer, which must be at least 0.1% larger than sourceLen plus
   12 bytes. Upon exit, destLen is the actual size of the compressed buffer.

     compress2 returns Z_OK if success, Z_MEM_ERROR if there was not enough
   memory, Z_BUF_ERROR if there was not enough room in the output buffer,
   Z_STREAM_ERROR if the level parameter is invalid.

	ZEXTERN int ZEXPORT compress2 OF((Bytef *dest,   uLongf *destLen,
                                  const Bytef *source, uLong sourceLen,
                                  int level));
	"

    <api: compress2 struct ulong struct ulong long ulong>
    ^self invalidArgument!   
gzrewind: file
	"
	Rewinds the given file. This function is supported only for reading.
   gzrewind(file) is equivalent to (int)gzseek(file, 0L, SEEK_SET)

	ZEXTERN int ZEXPORT    gzrewind OF((gzFile file));
	"

    <api: gzrewind long long>
    ^self invalidArgument! 
unzGetGlobalInfo: zipFile global: global
	"
	Write info about the ZipFile in the *pglobal_info structure.
  No preparation of the structure is needed
  return UNZ_OK if there is no problem.

	extern int ZEXPORT unzGetGlobalInfo OF((unzFile file,
                    unz_global_info *pglobal_info));
	"

    <api: unzGetGlobalInfo long struct long>
    ^self invalidArgument! 
deflateSetDictionary: stream dictionary: dictionary length: length
	"
	Initializes the compression dictionary from the given byte sequence
   without producing any compressed output. This function must be called
   immediately after deflateInit, deflateInit2 or deflateReset, before any
   call of deflate. The compressor and decompressor must use exactly the same
   dictionary (see inflateSetDictionary).

     The dictionary should consist of strings (byte sequences) that are likely
   to be encountered later in the data to be compressed, with the most commonly
   used strings preferably put towards the end of the dictionary. Using a
   dictionary is most useful when the data to be compressed is short and can be
   predicted with good accuracy; the data can then be compressed better than
   with the default empty dictionary.

     Depending on the size of the compression data structures selected by
   deflateInit or deflateInit2, a part of the dictionary may in effect be
   discarded, for example if the dictionary is larger than the window size in
   deflate or deflate2. Thus the strings most likely to be useful should be
   put at the end of the dictionary, not at the front.

     Upon return of this function, strm->adler is set to the Adler32 value
   of the dictionary; the decompressor may later use this value to determine
   which dictionary has been used by the compressor. (The Adler32 value
   applies to the whole dictionary even if only a subset of the dictionary is
   actually used by the compressor.)

     deflateSetDictionary returns Z_OK if success, or Z_STREAM_ERROR if a
   parameter is invalid (such as NULL dictionary) or the stream state is
   inconsistent (for example if deflate has already been called for this stream
   or if the compression method is bsort). deflateSetDictionary does not
   perform any compression: this will be done by deflate().

	ZEXTERN int ZEXPORT deflateSetDictionary OF((z_streamp strm,
                                             const Bytef *dictionary,
                                             uInt  dictLength));
	"

    <api: deflateSetDictionary struct struct ulong long>
    ^self invalidArgument!   
unzGetCurrentFileInfo: file info: info filename: fileName
	" Get Info about the current file. "

    ^self 
			unzGetCurrentFileInfo: file
			info: info
			filename: fileName fileNameSize: fileName size
			extraField: nil extraSize: 0
			comment: nil commentSize: 0!
inflateSetDictionary: stream dictionary: dictionary length: length
	"
	Initializes the decompression dictionary from the given uncompressed byte
   sequence. This function must be called immediately after a call of inflate
   if this call returned Z_NEED_DICT. The dictionary chosen by the compressor
   can be determined from the Adler32 value returned by this call of
   inflate. The compressor and decompressor must use exactly the same
   dictionary (see deflateSetDictionary).

     inflateSetDictionary returns Z_OK if success, Z_STREAM_ERROR if a
   parameter is invalid (such as NULL dictionary) or the stream state is
   inconsistent, Z_DATA_ERROR if the given dictionary doesn't match the
   expected one (incorrect Adler32 value). inflateSetDictionary does not
   perform any decompression: this will be done by subsequent calls of
   inflate().

	ZEXTERN int ZEXPORT inflateSetDictionary OF((z_streamp strm,
                                             const Bytef *dictionary,
                                             uInt  dictLength));
	"

    <api: inflateSetDictionary struct struct ulong long>
    ^self invalidArgument!  
zlibVersion
	"The application can compare zlibVersion and ZlibVersion
	 for consistency.
   If the first character differs, the library code actually used is
   not compatible with the zlib.h header file used by the application.
   This check is automatically made by deflateInit and inflateInit.

	ZEXTERN const char * ZEXPORT zlibVersion OF((void));
	"

    <api: zlibVersion ulongReturn>
    ^self invalidArgument!  
gzerror: file holder: error
	"
	Returns the error message for the last error which occurred on the
   given compressed file. errnum is set to zlib error number. If an
   error occurred in the file system and not in the compression library,
   errnum is set to Z_ERRNO and the application may consult errno
   to get the exact error code.

	ZEXTERN const char * ZEXPORT gzerror OF((gzFile file, int *errnum));
	"

    <api: gzerror long struct long>
    ^self invalidArgument!   
unzGoToNextFile: zipFile
	"
	Set the current file of the zipfile to the next file.
  return UNZ_OK if there is no problem
  return UNZ_END_OF_LIST_OF_FILE if the actual file was the latest.

	extern int ZEXPORT unzGoToNextFile OF((unzFile file));
	"

    <api: unzGoToNextFile long long>
    ^self invalidArgument!